@@ -7,7 +7,7 @@
 
 #include "spvm_compiler.h"
 #include "spvm_dumper.h"
-#include "spvm_array.h"
+#include "spvm_dynamic_array.h"
 #include "spvm_hash.h"
 #include "spvm_constant.h"
 #include "spvm_field.h"
@@ -134,12 +134,12 @@ void SPVM_DUMPER_dump_all(SPVM_COMPILER* compiler) {
   SPVM_DUMPER_dump_packages(compiler, compiler->op_packages);
 }
 
-void SPVM_DUMPER_dump_constants(SPVM_COMPILER* compiler, SPVM_ARRAY* op_constants) {
+void SPVM_DUMPER_dump_constants(SPVM_COMPILER* compiler, SPVM_DYNAMIC_ARRAY* op_constants) {
   {
     int32_t i;
     int32_t len;
     for (i = 0, len = op_constants->length; i < len; i++) {
-      SPVM_OP* op_constant = SPVM_ARRAY_fetch(op_constants, i);
+      SPVM_OP* op_constant = SPVM_DYNAMIC_ARRAY_fetch(op_constants, i);
       SPVM_CONSTANT* constant = op_constant->uv.constant;
       printf("    constant[%" PRId32 "]\n", i);
       SPVM_DUMPER_dump_constant(compiler, constant);
@@ -147,13 +147,13 @@ void SPVM_DUMPER_dump_constants(SPVM_COMPILER* compiler, SPVM_ARRAY* op_constant
   }
 }
 
-void SPVM_DUMPER_dump_packages(SPVM_COMPILER* compiler, SPVM_ARRAY* op_packages) {
+void SPVM_DUMPER_dump_packages(SPVM_COMPILER* compiler, SPVM_DYNAMIC_ARRAY* op_packages) {
   {
     int32_t i;
     int32_t len;
     for (i = 0, len = op_packages->length; i < len; i++) {
       printf("package[%" PRId32 "]\n", i);
-      SPVM_OP* op_package = SPVM_ARRAY_fetch(op_packages, i);
+      SPVM_OP* op_package = SPVM_DYNAMIC_ARRAY_fetch(op_packages, i);
       SPVM_PACKAGE* package = op_package->uv.package;
       printf("  name => \"%s\"\n", package->op_name->uv.name);
       
@@ -166,12 +166,12 @@ void SPVM_DUMPER_dump_packages(SPVM_COMPILER* compiler, SPVM_ARRAY* op_packages)
       
       // Field information
       printf("  fields\n");
-      SPVM_ARRAY* op_fields = package->op_fields;
+      SPVM_DYNAMIC_ARRAY* op_fields = package->op_fields;
       {
         int32_t j;
         int32_t len2;
         for (j = 0, len2 = op_fields->length; j < len2; j++) {
-          SPVM_OP* op_field = SPVM_ARRAY_fetch(op_fields, j);
+          SPVM_OP* op_field = SPVM_DYNAMIC_ARRAY_fetch(op_fields, j);
           SPVM_FIELD* field = op_field->uv.field;
           printf("    field%" PRId32 "\n", j);
           SPVM_DUMPER_dump_field(compiler, field);
@@ -180,11 +180,11 @@ void SPVM_DUMPER_dump_packages(SPVM_COMPILER* compiler, SPVM_ARRAY* op_packages)
       
       // Sub information
       printf("  subs\n");
-      SPVM_ARRAY* op_subs = package->op_subs;
+      SPVM_DYNAMIC_ARRAY* op_subs = package->op_subs;
       {
         int32_t i;
         for (i = 0, len = op_subs->length; i < len; i++) {
-          SPVM_OP* op_sub = SPVM_ARRAY_fetch(op_subs, i);
+          SPVM_OP* op_sub = SPVM_DYNAMIC_ARRAY_fetch(op_subs, i);
           SPVM_SUB* sub = op_sub->uv.sub;
           printf("    sub%" PRId32 "\n", i);
           SPVM_DUMPER_dump_sub(compiler, sub);
@@ -194,7 +194,7 @@ void SPVM_DUMPER_dump_packages(SPVM_COMPILER* compiler, SPVM_ARRAY* op_packages)
   }
 }
 
-void SPVM_DUMPER_dump_types(SPVM_COMPILER* compiler, SPVM_ARRAY* types) {
+void SPVM_DUMPER_dump_types(SPVM_COMPILER* compiler, SPVM_DYNAMIC_ARRAY* types) {
   (void)compiler;
   
   {
@@ -202,7 +202,7 @@ void SPVM_DUMPER_dump_types(SPVM_COMPILER* compiler, SPVM_ARRAY* types) {
     int32_t len;
     for (i = 0, len = types->length; i < len; i++) {
       printf("type[%" PRId32 "]\n", i);
-      SPVM_TYPE* type = SPVM_ARRAY_fetch(types, i);
+      SPVM_TYPE* type = SPVM_DYNAMIC_ARRAY_fetch(types, i);
       printf("    name => \"%s\"\n", type->name);
       printf("    id => \"%" PRId32 "\"\n", type->id);
     }
@@ -510,12 +510,12 @@ void SPVM_DUMPER_dump_sub(SPVM_COMPILER* compiler, SPVM_SUB* sub) {
     printf("      is_native => %d\n", sub->is_native);
     
     printf("      args\n");
-    SPVM_ARRAY* op_args = sub->op_args;
+    SPVM_DYNAMIC_ARRAY* op_args = sub->op_args;
     {
       int32_t i;
       int32_t len;
       for (i = 0, len = op_args->length; i < len; i++) {
-        SPVM_OP* op_arg = SPVM_ARRAY_fetch(sub->op_args, i);
+        SPVM_OP* op_arg = SPVM_DYNAMIC_ARRAY_fetch(sub->op_args, i);
         SPVM_MY_VAR* my_var = op_arg->uv.my_var;
         printf("        arg[%" PRId32 "]\n", i);
         SPVM_DUMPER_dump_my_var(compiler, my_var);
@@ -524,12 +524,12 @@ void SPVM_DUMPER_dump_sub(SPVM_COMPILER* compiler, SPVM_SUB* sub) {
     
     if (!sub->is_native) {
       printf("      my_vars\n");
-      SPVM_ARRAY* op_my_vars = sub->op_my_vars;
+      SPVM_DYNAMIC_ARRAY* op_my_vars = sub->op_my_vars;
       {
         int32_t i;
         int32_t len;
         for (i = 0, len = op_my_vars->length; i < len; i++) {
-          SPVM_OP* op_my_var = SPVM_ARRAY_fetch(sub->op_my_vars, i);
+          SPVM_OP* op_my_var = SPVM_DYNAMIC_ARRAY_fetch(sub->op_my_vars, i);
           SPVM_MY_VAR* my_var = op_my_var->uv.my_var;
           printf("        my_var[%" PRId32 "]\n", i);
           SPVM_DUMPER_dump_my_var(compiler, my_var);
